{
  description = "Annotator";

  inputs = {
    nixpkgs = {
      url = "nixpkgs/nixos-23.05";
    };
    flake-utils = {
      url = "github:numtide/flake-utils";
    };
  };
  outputs = { self, nixpkgs, flake-utils, ... }@inputs:
    flake-utils.lib.eachDefaultSystem
      (system:
        let
          pkgs = import nixpkgs {
            inherit system;
          };
        in
        {
          packages = {
            annotator =
              let
                pname = "annotator";
                version = "1.2.1";
              in
              pkgs.stdenv.mkDerivation {
                inherit pname version;
                src = pkgs.fetchFromGitHub {
                  owner = "phase1geo";
                  repo = "Annotator";
                  rev = version;
                  hash = "sha256-VHvznkGvrE8o9qq+ijrIStSavq46dS8BqclWEWZ8mG8=";
                };
                buildInputs = [
                  pkgs.glib
                  pkgs.gtk3
                  pkgs.libgee
                  pkgs.libhandy
                  pkgs.libxml2
                  pkgs.pantheon.granite
                ];
                nativeBuildInputs = [
                  pkgs.desktop-file-utils
                  pkgs.meson
                  pkgs.ninja
                  pkgs.pkg-config
                  pkgs.vala
                  pkgs.wrapGAppsHook
                ];
                meta = {
                  homepage = "https://github.com/phase1geo/Annotator";
                  description = "Image annotation for Elementary OS ";
                  longDescription = ''
                    Annotate your images and let a picture say 1000 words.

                    *  Load image from the file system or clipboard.
                    *  Add shapes, stickers, text, drawings, and other callouts to highlight image details.
                    *  Add magnifiers to enhance image details.
                    *  Blur out portions of the image to obfuscate data.
                    *  Crop, resize and add image borders.
                    *  Control colors, line thickness and font details.
                    *  Zoom support.
                    *  Unlimited undo/redo of any change.
                    *  Export to JPEG, PNG, TIFF, BMP, PDF and SVG image formats.
                    *  Support for copying annotated image to clipboard.
                    *  Printer support.
                  '';
                };
              };

          };
        }
      );
}
